==> huaweicloudsdkgaussdb-3.1.111-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/upgrade_proxy_version_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpgradeProxyVersionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'update_result': 'list[ProxyUpgradeVersionDetail]'
    }

    attribute_map = {
        'update_result': 'update_result'
    }

    def __init__(self, update_result=None):
        """UpgradeProxyVersionResponse

        The model defined in huaweicloud sdk

        :param update_result: 数据库代理升级信息列表。
        :type update_result: list[:class:`huaweicloudsdkgaussdb.v3.ProxyUpgradeVersionDetail`]
        """
        
        super(UpgradeProxyVersionResponse, self).__init__()

        self._update_result = None
        self.discriminator = None

        if update_result is not None:
            self.update_result = update_result

    @property
    def update_result(self):
        """Gets the update_result of this UpgradeProxyVersionResponse.

        数据库代理升级信息列表。

        :return: The update_result of this UpgradeProxyVersionResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdb.v3.ProxyUpgradeVersionDetail`]
        """
        return self._update_result

    @update_result.setter
    def update_result(self, update_result):
        """Sets the update_result of this UpgradeProxyVersionResponse.

        数据库代理升级信息列表。

        :param update_result: The update_result of this UpgradeProxyVersionResponse.
        :type update_result: list[:class:`huaweicloudsdkgaussdb.v3.ProxyUpgradeVersionDetail`]
        """
        self._update_result = update_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeProxyVersionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/upgrade_proxy_version_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpgradeProxyVersionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'update_result': 'list[ProxyUpgradeVersionDetail]'
    }

    attribute_map = {
        'update_result': 'update_result'
    }

    def __init__(self, update_result=None):
        r"""UpgradeProxyVersionResponse

        The model defined in huaweicloud sdk

        :param update_result: 数据库代理升级信息列表。
        :type update_result: list[:class:`huaweicloudsdkgaussdb.v3.ProxyUpgradeVersionDetail`]
        """
        
        super(UpgradeProxyVersionResponse, self).__init__()

        self._update_result = None
        self.discriminator = None

        if update_result is not None:
            self.update_result = update_result

    @property
    def update_result(self):
        r"""Gets the update_result of this UpgradeProxyVersionResponse.

        数据库代理升级信息列表。

        :return: The update_result of this UpgradeProxyVersionResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdb.v3.ProxyUpgradeVersionDetail`]
        """
        return self._update_result

    @update_result.setter
    def update_result(self, update_result):
        r"""Sets the update_result of this UpgradeProxyVersionResponse.

        数据库代理升级信息列表。

        :param update_result: The update_result of this UpgradeProxyVersionResponse.
        :type update_result: list[:class:`huaweicloudsdkgaussdb.v3.ProxyUpgradeVersionDetail`]
        """
        self._update_result = update_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeProxyVersionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
